@@ -11,7 +11,6 @@ import os
 from collections import defaultdict, namedtuple
 from copy import deepcopy
 from subprocess import call
-from typing import List, Tuple
 from unittest import TestCase, main
 
 import pytest
@@ -309,8 +308,7 @@ class TestUdmGenericVariousModules(TestCase):
             sup_modules = [sup_modules]
         for sup_module in sup_modules:
             for obj in self.udm.get(sup_module).search():
-                print('Using {!r} object at {!r} as superordinate for model of {!r} object.'.format(
-                    sup_module, obj.dn, mod.name))
+                print(f'Using {sup_module!r} object at {obj.dn!r} as superordinate for model of {mod.name!r} object.')
                 return mod.new(obj)
         raise exc_thrown.with_traceback(None)
 
@@ -696,7 +694,7 @@ def simple_udm(ucr) -> UDM:
 
 @pytest.fixture()
 def schedule_delete_udm_obj(simple_udm):
-    objs: List[Tuple[str, str]] = []
+    objs: list[tuple[str, str]] = []
 
     def _func(dn: str, udm_mod: str) -> None:
         objs.append((dn, udm_mod))
