@@ -38,7 +38,7 @@ def test_app_scaling(appcenter, app_name, app_version):
             apps[i].install()
 
         for i in range(DOCKER_APP_COUNT):
-            apps[i].verify(joined=False)
+            apps[i].verify()
             apps[i].configure_tinyapp_modproxy()
             apps[i].verify_basic_modproxy_settings_tinyapp()
 
